yakumo.keystone.v2.service.Resource

Package yakumo :: Package keystone :: Package v2 :: Module service :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

resource class for services on Identity V2 API

Instance Methods | [hide private]
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `update`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`